@@ -6,7 +6,7 @@ use warnings;
 use 5.008;
 
 use LWP::UserAgent;
-use URI::Escape;
+use URI;
 
 =head1 NAME
 
@@ -14,11 +14,11 @@ Net::FileMaker - Interact with FileMaker services
 
 =head1 VERSION
 
-Version 0.05
+Version 0.06
 
 =cut
 
-our $VERSION = 0.05_01;
+our $VERSION = 0.06;
 
 =head1 SYNOPSIS
 
@@ -69,6 +69,11 @@ As all of the current structure is confied to the XML base, see L<Net::FileMaker
 
 Squeeks, C<< <squeek at cpan.org> >>
 
+=head1 CONTRIBUTORS
+
+Simon Cozens, C<<simon at cpan.org>>
+Marcel Grünauer, C<<marcel at cpan.org>>
+
 =head1 BUGS
 
 This distrobution is in it's early stages and B<things will be prone to breaking and changing in future versions>. 
